Ambiente = {
    '1': '1 - Produccion',
    '2': '2 - Pruebas',
}


TipoDocumento = {
    '11': '11 - Registro civil',
    '12': '12 - Tarjeta de identidad',
    '13': '13 - Cédula de ciudadanía',
    '21': '21 - Tarjeta de extranjería',
    '22': '22 - Cédula de extranjería',
    '31': '31 - NIT',
    '41': '41 - Pasaporte',
    '42': '42 - Documento de identificación extranjero',
    '47': '47 - PEP',
    '50': '50 - NIT de otro país',
    '91': '91 - NUIP * ',
}